# Linformer Pytorch Implementation
A practical implementation of the [Linformer paper](https://arxiv.org/pdf/2006.04768.pdf).

This is a self attention mechanism with linear time complexity in n.

Check out the github for more information: https://github.com/tatp22/linformer-pytorch
